# YIO API V2 Python library

YIO Software V2 API Python library, that is used (for now) to integrate with Home Assistant.

Currently only token send is implemented for the YIO API external token registry, as this is required by the Home Assistant integration for seamless UI setup.

Considered as proof of concept.